@@ -145,7 +145,7 @@ grammar = {
             # a=ptime:20
             'name': 'ptime',
             'reg': "^ptime:(\d*(?:\.\d*)*)",
-            'format': lambda o: 'ptime:%d' if isinstance(o, int) else 'ptime:%f'
+            'format': lambda o: 'ptime:%d' if isinstance(o, int) else 'ptime:%g'
         },
         {
             # a=maxptime:60
@@ -431,4 +431,4 @@ for key in grammar.keys():
         if not obj.get('reg'):
             obj['reg'] = r'(.*)'
         if not obj.get('format'):
-            obj['format'] = '%s'
\ No newline at end of file
+            obj['format'] = '%s'
